csep.core.catalogs.CSEPCatalog
==============================

.. currentmodule:: csep.core.catalogs

.. autoclass:: CSEPCatalog

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CSEPCatalog.__init__
      ~CSEPCatalog.apply_mct
      ~CSEPCatalog.filter
      ~CSEPCatalog.filter_spatial
      ~CSEPCatalog.from_dataframe
      ~CSEPCatalog.from_dict
      ~CSEPCatalog.get_bvalue
      ~CSEPCatalog.get_csep_format
      ~CSEPCatalog.get_cumulative_number_of_events
      ~CSEPCatalog.get_datetimes
      ~CSEPCatalog.get_depths
      ~CSEPCatalog.get_epoch_times
      ~CSEPCatalog.get_event_ids
      ~CSEPCatalog.get_latitudes
      ~CSEPCatalog.get_longitudes
      ~CSEPCatalog.get_mag_idx
      ~CSEPCatalog.get_magnitudes
      ~CSEPCatalog.get_number_of_events
      ~CSEPCatalog.get_spatial_idx
      ~CSEPCatalog.length_in_seconds
      ~CSEPCatalog.load_ascii_catalogs
      ~CSEPCatalog.load_catalog
      ~CSEPCatalog.load_json
      ~CSEPCatalog.magnitude_counts
      ~CSEPCatalog.spatial_counts
      ~CSEPCatalog.spatial_event_probability
      ~CSEPCatalog.spatial_magnitude_counts
      ~CSEPCatalog.to_dataframe
      ~CSEPCatalog.to_dict
      ~CSEPCatalog.update_catalog_stats
      ~CSEPCatalog.write_ascii
      ~CSEPCatalog.write_json
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CSEPCatalog.catalog
      ~CSEPCatalog.data
      ~CSEPCatalog.dtype
      ~CSEPCatalog.event_count
      ~CSEPCatalog.log
   
   